package org.grails.jquery.datatables.tabletools

import grails.test.*
import org.codehaus.groovy.grails.commons.GrailsApplication
import groovy.util.ConfigObject
import org.gmock.*
import static org.hamcrest.Matchers.*

@WithGMock
class JQueryDataTableToolsTagLibTests extends TagLibUnitTestCase {

	def minifiedFile = "tableTools.min.js"
	def file = "tableTools.js"
	def cssFile = "tableTools.css"
	def clipboard = "zeroClipboard.js"
	
	def pluginName = "tableTools"

	def fakeUrlForJs = 'path/to/table-tools.js'
	def fakeUrlForCss = 'path/to/table-tools.css'

	def g, mockConfig

	protected void setUp() {
		super.setUp()
		mockConfig = [config:[tableTools: [minified:false]]]
		tagLib.metaClass.getGrailsApplication = {-> mockConfig}
		g = mock()
	}

	protected void tearDown() {
		super.tearDown()
	}

	void testResourcesWithNoAttributes() {
		shouldFail(NullPointerException){
			tagLib.metaClass.getGrailsApplication = {-> mockConfig}
			tagLib.resources()
		}
	}

	void testResourcesWithJsTypeAttributeAndMinifiedFalse(){
		mock(tagLib).g.returns(g).times(2)		
		g.resource([plugin:pluginName, dir:"js", file:file]).returns(fakeUrlForJs)
		g.resource([plugin:pluginName, dir:"js", file:clipboard]).returns(fakeUrlForJs)
		
		play{
			tagLib.resources(type:'js')
			println tagLib.out.toString()
			assertTrue "Missing ' type=\"text/javascript\" '", tagLib.out.toString().contains(' type="text/javascript" ')
			assertTrue "Missing '<script '", tagLib.out.toString().contains('<script ')
			assertTrue "Missing '</script>'", tagLib.out.toString().contains('</script>')
			assertTrue "Missing ' src=\"${fakeUrlForJs}\">'", tagLib.out.toString().contains(" src=\"${fakeUrlForJs}\">")
		}
	}

	void testResourcesWithCssTypeAttributeAndMinifiedFalse(){
		mock(tagLib).g.returns(g)		
		g.resource([plugin:pluginName, dir:"css", file:cssFile]).returns(fakeUrlForCss)

		play{
			tagLib.resources(type:'css')
			println tagLib.out.toString()
			assertTrue "Missing '<link '", tagLib.out.toString().contains('<link ')
			assertTrue "Missing 'rel=\"stylesheet\" '", tagLib.out.toString().contains('rel="stylesheet" ')
			assertTrue "Missing 'type=\"text/css\" '", tagLib.out.toString().contains('type="text/css" ')
			assertTrue "Missing 'media=\"screen\" '", tagLib.out.toString().contains('media="screen" ')
			assertTrue "Missing href=\"${fakeUrlForCss}\" />'", tagLib.out.toString().contains("href=\"${fakeUrlForCss}\" />")
		}
	}

	void testResourcesWithJsTypeAttributeAndMinifiedTrue(){
		mock(tagLib).g.returns(g).times(2)		
		mockConfig.config.tableTools.minified = true
		g.resource([plugin:pluginName, dir:"js", file:minifiedFile]).returns(fakeUrlForJs)
		g.resource([plugin:pluginName, dir:"js", file:clipboard]).returns(fakeUrlForJs)
		
		play{
			tagLib.resources(type:'js')
			println tagLib.out.toString()
			assertTrue "Missing ' type=\"text/javascript\" '", tagLib.out.toString().contains(' type="text/javascript" ')
			assertTrue "Missing '<script '", tagLib.out.toString().contains('<script ')
			assertTrue "Missing '</script>'", tagLib.out.toString().contains('</script>')
			assertTrue "Missing ' src=\"${fakeUrlForJs}\">'", tagLib.out.toString().contains(" src=\"${fakeUrlForJs}\">")
		}
	}

	void testResourcesWithCssTypeAttributeAndMinifiedTrue(){
		mock(tagLib).g.returns(g)		
		mockConfig.config.tableTools.minified = true
		g.resource([plugin:pluginName, dir:"css", file:cssFile]).returns(fakeUrlForCss)
		
		play{
			tagLib.resources(type:'css')
			println tagLib.out.toString()
			assertTrue "Missing '<link '", tagLib.out.toString().contains('<link ')
			assertTrue "Missing 'rel=\"stylesheet\" '", tagLib.out.toString().contains('rel="stylesheet" ')
			assertTrue "Missing 'type=\"text/css\" '", tagLib.out.toString().contains('type="text/css" ')
			assertTrue "Missing 'media=\"screen\" '", tagLib.out.toString().contains('media="screen" ')
			assertTrue "Missing href=\"${fakeUrlForCss}\" />'", tagLib.out.toString().contains("href=\"${fakeUrlForCss}\" />")
		}
	}
}
